import type { AccountId } from "../models/AccountId";
import type { AsyncResponse } from "../models/AsyncResponse";
import type { CopyFolderBatchRequest } from "../models/CopyFolderBatchRequest";
import type { CopyFolderRequest } from "../models/CopyFolderRequest";
import type { DeleteFolderBatchRequest } from "../models/DeleteFolderBatchRequest";
import type { DeleteFolderRequest } from "../models/DeleteFolderRequest";
import type { FolderDetails } from "../models/FolderDetails";
import type { FolderPath } from "../models/FolderPath";
import type { IncludeFiles } from "../models/IncludeFiles";
import type { IncludeOverriddenStorage } from "../models/IncludeOverriddenStorage";
import type { IncludePhysicalFolders } from "../models/IncludePhysicalFolders";
import type { IncludeVirtualFolders } from "../models/IncludeVirtualFolders";
import type { IterateFolderRecursively } from "../models/IterateFolderRecursively";
import type { ListFolderChildrenResponse } from "../models/ListFolderChildrenResponse";
import type { ListFolderCursor } from "../models/ListFolderCursor";
import type { ListFolderDryRun } from "../models/ListFolderDryRun";
import type { ListFolderItemLimit } from "../models/ListFolderItemLimit";
import type { ListFolderResponse } from "../models/ListFolderResponse";
import type { PutFolderRequest } from "../models/PutFolderRequest";
export declare class FolderService {
    /**
     * Creates or updates the folder specified by the `folderPath`.
     *
     * If the folder's ancestors do not exist, they will be created automatically (with empty FolderSettings).
     *
     * Note: you don't need to create folders before uploading files to them.
     * @param accountId
     * @param requestBody
     * @returns FolderDetails Success.
     * @throws ApiError
     */
    static putFolder(accountId: AccountId, requestBody: PutFolderRequest): Promise<FolderDetails>;
    /**
     * Gets the full details (e.g. permission, storage layer, etc.) for a folder.
     *
     * Returns an empty object if no settings have been configured for this folder.
     * @param accountId
     * @param folderPath
     * @returns FolderDetails Success.
     * @throws ApiError
     */
    static getFolderDetails(accountId: AccountId, folderPath: FolderPath): Promise<FolderDetails>;
    /**
     * Deletes a folder asynchronously.
     *
     * If the folder has overridden storage settings, then no files will be deleted.
     *
     * You can use ListFolder to preview the operation: set `dryRun=true` with ```recursive```, ```includeFiles``` and ```includeVirtualFolders``` set to match the values you're using here. Leave all other flags unset.
     * @param accountId
     * @param requestBody
     * @returns AsyncResponse Success.
     * @throws ApiError
     */
    static deleteFolder(accountId: AccountId, requestBody: DeleteFolderRequest): Promise<AsyncResponse>;
    /**
     * Lists the children (files and sub-folders) of a folder.
     * @param accountId
     * @param folderPath
     * @param cursor
     * @param includeFiles
     * @param includeFolders
     * @param internal
     * @param limit
     * @returns ListFolderChildrenResponse Success.
     * @throws ApiError
     */
    static listFolderChildren(accountId: AccountId, folderPath: FolderPath, cursor?: ListFolderCursor, includeFiles?: IncludeFiles, includeFolders?: boolean, internal?: boolean, limit?: ListFolderItemLimit): Promise<ListFolderChildrenResponse>;
    /**
     * Lists the folder's contents.
     *
     * The result may be paginated: subsequent pages can be requested by passing the ```cursor``` from the response into the ```cursor``` request parameter.
     *
     * Pagination is complete when the response includes `isPaginationComplete=true`.
     * @param accountId
     * @param folderPath
     * @param cursor
     * @param dryRun
     * @param includeFiles
     * @param includeOverriddenStorage
     * @param includePhysicalFolders
     * @param includeVirtualFolders
     * @param limit
     * @param recursive
     * @returns ListFolderResponse Success.
     * @throws ApiError
     */
    static listFolder(accountId: AccountId, folderPath: FolderPath, cursor?: ListFolderCursor, dryRun?: ListFolderDryRun, includeFiles?: IncludeFiles, includeOverriddenStorage?: IncludeOverriddenStorage, includePhysicalFolders?: IncludePhysicalFolders, includeVirtualFolders?: IncludeVirtualFolders, limit?: ListFolderItemLimit, recursive?: IterateFolderRecursively): Promise<ListFolderResponse>;
    /**
     * Copies a folder asynchronously.
     *
     * You can use ListFolder to preview the operation: set `dryRun=true` with ```recursive```, ```includeFiles```, ```includeOverriddenStorage``` and ```includeVirtualFolders``` set to match the values you're using here. Leave all other flags unset.
     * @param accountId
     * @param requestBody
     * @returns AsyncResponse Success.
     * @throws ApiError
     */
    static copyFolder(accountId: AccountId, requestBody: CopyFolderRequest): Promise<AsyncResponse>;
    /**
     * Copies multiple folders asynchronously.
     *
     * You can use ListFolder to preview the operation: set `dryRun=true` with ```recursive```, ```includeFiles```, ```includeOverriddenStorage``` and ```includeVirtualFolders``` set to match the values you're using here. Leave all other flags unset.
     * @param accountId
     * @param requestBody
     * @returns AsyncResponse Success.
     * @throws ApiError
     */
    static copyFolderBatch(accountId: AccountId, requestBody: CopyFolderBatchRequest): Promise<AsyncResponse>;
    /**
     * Deletes multiple folders asynchronously.
     *
     * If the folder has overridden storage settings, then no files will be deleted.
     *
     * You can use ListFolder to preview the operation: set `dryRun=true` with ```recursive```, ```includeFiles``` and ```includeVirtualFolders``` set to match the values you're using here. Leave all other flags unset.
     * @param accountId
     * @param requestBody
     * @returns AsyncResponse Success.
     * @throws ApiError
     */
    static deleteFolderBatch(accountId: AccountId, requestBody: DeleteFolderBatchRequest): Promise<AsyncResponse>;
}
